@@ -103,10 +103,10 @@ class Renderer(JsRenderer, JsCacheRenderer):
             site_title=settings.SITE.title,
             )
 
-        if settings.SITE.never_build_site_cache:
-            data.update(revision_number=settings.SITE.kernel.lino_version)
-        else:
-            data.update(revision_number=settings.SITE.kernel.code_mtime)
+        # if settings.SITE.never_build_site_cache:
+        #     data.update(revision_number=settings.SITE.kernel.lino_version)
+        # else:
+        data.update(revision_number=settings.SITE.kernel.code_mtime)
 
         if hasattr(settings.SITE, 'theme_name'):
             data.update(theme_name=settings.SITE.theme_name)
@@ -483,7 +483,7 @@ class Renderer(JsRenderer, JsCacheRenderer):
                                                 ttt))
 
     def lino_js_parts_chunked(self, actorId):
-        """ Like lino_js_parts, but for actor_level data"""
+        """Like lino_js_parts, but for actor_level data"""
         user_type = get_user_profile()
         filename = 'Lino_' + actorId + "_"
         file_type = self.lino_web_template.rsplit(".")[-1]  # json
@@ -674,6 +674,7 @@ class Renderer(JsRenderer, JsCacheRenderer):
         return result
 
     def build_js_cache(self, force):
+        # assert self.serialise_js_code is False
         self.serialise_js_code = True
 
         for actor in self.actors_list:
@@ -682,12 +683,9 @@ class Renderer(JsRenderer, JsCacheRenderer):
             fn = path.join(*self.lino_js_parts_chunked(actor.actor_id))
 
             def write(f):
-                f.write(
-                    py2js(self.actor2json(actor))
-                )
+                f.write(py2js(self.actor2json(actor)))
 
             settings.SITE.kernel.make_cache_file(fn, write, force)
 
         self.serialise_js_code = False
-
-        return super(Renderer, self).build_js_cache(force)
+        return super().build_js_cache(force)
