@@ -684,10 +684,9 @@ class UserSettings(View):
                 dashboard_items=len(u.get_preferences().dashboard_items),
                 email=u.email,
                 # [d.serialize() for d in u.get_preferences().dashboard_items],
-                lv=str(settings.SITE.kernel.code_mtime),
                 lang=get_language(),
                 site_data=settings.SITE.build_site_cache_url(*settings.SITE.plugins.react.renderer.lino_js_parts()),
-                site_name=settings.SITE.site_dir.name,
+                site_name=settings.SITE.project_dir.name,
                 logged_in=not_anon,
                 username=u.get_full_name() if not_anon else _("Anonymous"),
                 su_name=su_name,  # subst_user # must be passed as param in get_user_settings request,
